
.. _`WBEM operation statistics`:

WBEM operation statistics
-------------------------

.. automodule:: pywbem._statistics

.. autoclass:: pywbem.Statistics
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.OperationStatistic
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:
